==> R14.1.1-core.tar: tdegraphics-trinity-14.1.1/kpovmodeler/pmtranslateedit.cpp <==
/*
**************************************************************************
                                 description
                             --------------------
    copyright            : (C) 2000-2001 by Andreas Zehender
    email                : zehender@kde.org
**************************************************************************

**************************************************************************
*                                                                        *
*  This program is free software; you can redistribute it and/or modify  *
*  it under the terms of the GNU General Public License as published by  *
*  the Free Software Foundation; either version 2 of the License, or     *
*  (at your option) any later version.                                   *
*                                                                        *
**************************************************************************/


#include "pmtranslateedit.h"
#include "pmtranslate.h"
#include "pmvectoredit.h"

#include <tqlayout.h>
#include <tdelocale.h>


PMTranslateEdit::PMTranslateEdit( TQWidget* parent, const char* name )
      : Base( parent, name )
{
   m_pDisplayedObject = 0;
}

void PMTranslateEdit::createTopWidgets( )
{
   Base::createTopWidgets( );

   m_pVector = new PMVectorEdit( "x", "y", "z", this );
   topLayout( )->addWidget( m_pVector );

   connect( m_pVector, TQT_SIGNAL( dataChanged( ) ), TQT_SIGNAL( dataChanged( ) ) );
}

void PMTranslateEdit::displayObject( PMObject* o )
{
   if( o->isA( "Translate" ) )
   {
      bool readOnly = o->isReadOnly( );
      m_pDisplayedObject = ( PMTranslate* ) o;

      m_pVector->setVector( m_pDisplayedObject->translation( ) );
      m_pVector->setReadOnly( readOnly );
      
      Base::displayObject( o );
   }
   else
      kdError( PMArea ) << "PMTranslateEdit: Can't display object\n";
}

void PMTranslateEdit::saveContents( )
{
   if( m_pDisplayedObject )
   {
      Base::saveContents( );
      m_pDisplayedObject->setTranslation( m_pVector->vector( ) );
   }
}

bool PMTranslateEdit::isDataValid( )
{
   if( m_pVector->isDataValid( ) )
      return Base::isDataValid( );
   return false;
}
#include "pmtranslateedit.moc"

==> R14.1.4-core.tar: tdegraphics-trinity-14.1.4/kpovmodeler/pmtranslateedit.cpp <==
/*
**************************************************************************
                                 description
                             --------------------
    copyright            : (C) 2000-2001 by Andreas Zehender
    email                : zehender@kde.org
**************************************************************************

**************************************************************************
*                                                                        *
*  This program is free software; you can redistribute it and/or modify  *
*  it under the terms of the GNU General Public License as published by  *
*  the Free Software Foundation; either version 2 of the License, or     *
*  (at your option) any later version.                                   *
*                                                                        *
**************************************************************************/


#include "pmtranslateedit.h"
#include "pmtranslate.h"
#include "pmvectoredit.h"

#include <tqlayout.h>
#include <tdelocale.h>


PMTranslateEdit::PMTranslateEdit( TQWidget* parent, const char* name )
      : Base( parent, name )
{
   m_pDisplayedObject = 0;
}

void PMTranslateEdit::createTopWidgets( )
{
   Base::createTopWidgets( );

   m_pVector = new PMVectorEdit( "x", "y", "z", this );
   topLayout( )->addWidget( m_pVector );

   connect( m_pVector, TQ_SIGNAL( dataChanged( ) ), TQ_SIGNAL( dataChanged( ) ) );
}

void PMTranslateEdit::displayObject( PMObject* o )
{
   if( o->isA( "Translate" ) )
   {
      bool readOnly = o->isReadOnly( );
      m_pDisplayedObject = ( PMTranslate* ) o;

      m_pVector->setVector( m_pDisplayedObject->translation( ) );
      m_pVector->setReadOnly( readOnly );
      
      Base::displayObject( o );
   }
   else
      kdError( PMArea ) << "PMTranslateEdit: Can't display object\n";
}

void PMTranslateEdit::saveContents( )
{
   if( m_pDisplayedObject )
   {
      Base::saveContents( );
      m_pDisplayedObject->setTranslation( m_pVector->vector( ) );
   }
}

bool PMTranslateEdit::isDataValid( )
{
   if( m_pVector->isDataValid( ) )
      return Base::isDataValid( );
   return false;
}
#include "pmtranslateedit.moc"
